@@ -10,13 +10,15 @@ from scipy.io.wavfile import read
 
 from ruth_tts_transformer.utils.stft import STFT
 
-git_voice_download = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..')
-
-os.system(f"cd {git_voice_download} && git init  && git remote add origin "
-          f"https://github.com/prakashr7d/ruth-tts-files.git && "
-          f"git pull origin main && git checkout main -f  ")
-
 BUILTIN_VOICES_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../voices')
+if not os.path.isdir(BUILTIN_VOICES_DIR):
+    git_voice_download = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..')
+
+    os.system(f"cd {git_voice_download} && git init  && git remote add origin "
+              f"https://github.com/prakashr7d/ruth-tts-files.git && "
+              f"git pull origin main && git checkout main -f  ")
+
+BUILTIN_VOICqES_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../voices')
 
 
 def load_wav_to_torch(full_path):
@@ -66,7 +68,7 @@ TACOTRON_MEL_MIN = -11.512925148010254
 
 
 def denormalize_tacotron_mel(norm_mel):
-    return ((norm_mel+1)/2)*(TACOTRON_MEL_MAX-TACOTRON_MEL_MIN)+TACOTRON_MEL_MIN
+    return ((norm_mel + 1) / 2) * (TACOTRON_MEL_MAX - TACOTRON_MEL_MIN) + TACOTRON_MEL_MIN
 
 
 def normalize_tacotron_mel(mel):
@@ -129,17 +131,19 @@ def load_voices(voices, extra_voice_dirs=[]):
             return None, None
         clip, latent = load_voice(voice, extra_voice_dirs)
         if latent is None:
-            assert len(latents) == 0, "Can only combine raw audio voices or latent voices, not both. Do it yourself if you want this."
+            assert len(
+                latents) == 0, "Can only combine raw audio voices or latent voices, not both. Do it yourself if you want this."
             clips.extend(clip)
         elif clip is None:
-            assert len(clips) == 0, "Can only combine raw audio voices or latent voices, not both. Do it yourself if you want this."
+            assert len(
+                clips) == 0, "Can only combine raw audio voices or latent voices, not both. Do it yourself if you want this."
             latents.append(latent)
     if len(latents) == 0:
         return clips, None
     else:
         latents_0 = torch.stack([l[0] for l in latents], dim=0).mean(dim=0)
         latents_1 = torch.stack([l[1] for l in latents], dim=0).mean(dim=0)
-        latents = (latents_0,latents_1)
+        latents = (latents_0, latents_1)
         return None, latents
 
 
@@ -175,8 +179,8 @@ class TacotronSTFT(torch.nn.Module):
         -------
         mel_output: torch.FloatTensor of shape (B, n_mel_channels, T)
         """
-        assert(torch.min(y.data) >= -10)
-        assert(torch.max(y.data) <= 10)
+        assert (torch.min(y.data) >= -10)
+        assert (torch.max(y.data) <= 10)
         y = torch.clip(y, min=-1, max=1)
 
         magnitudes, phases = self.stft_fn.transform(y)
